@@ -3,19 +3,13 @@ import warnings
 # try to import tesbml or libsbml
 # if both of these fail, libsbml cannot be imported - cannot continue
 try:
-
     import tesbml as libsbml   
 except ImportError:
     import libsbml
 
 from math import isnan
 from re import sub
-import os
-
-# Version info is in __init__.py
-
-def runUnitTests():
-    print (os.getcwd())
+import os, sys
 
 def _isSBMLModel(obj):
   """
